﻿Public Class CalcForm
    Function CalcGrossPay(ByVal dblHourlyWage As Double, ByVal intHoursWorked As Integer) As Double
        'calculates gross pay
        Dim dblGrossPay As Double

        'error handling/ validating hours
        If intHoursWorked > 40 Then
            'calculates wage with overtime
            dblGrossPay = (dblHourlyWage * 40) + (dblHourlyWage * (intHoursWorked - 40) * 1.5)
        ElseIf intHoursWorked > 0 And intHoursWorked <= 40 Then
            'calculates wage without overtime
            dblGrossPay = dblHourlyWage * intHoursWorked
        Else
            MessageBox.Show("Please input a value greater than 0.", "Error: Hours Worked",
                            MessageBoxButtons.OK, MessageBoxIcon.Hand)
        End If

        Return dblGrossPay
    End Function
    Function CalcFICA(ByVal dblGrossPay As Double) As Double
        'calculates FICA Taxes
        Dim dblFICA As Double
        Const dblFICARate As Double = 0.0765

        dblFICA = dblGrossPay * dblFICARate

        Return dblFICA
    End Function
    Function CalcTaxableWage(ByVal dblGrossPay As Double, ByVal intDependents As Integer, ByVal dblFICA As Double) As Double
        'calculates Taxable Wage
        Dim dblTaxableWage As Double
        Const dblDependentRate As Double = 70.19

        dblTaxableWage = dblGrossPay - (dblDependentRate * intDependents) - dblFICA

        Return dblTaxableWage
    End Function
    Function CalcFedTaxSingle(ByVal dblTaxableWage As Double) As Double
        'calculates Federal taxes if you are single
        Dim dblFedTax As Double

        'goes through the Single table
        Select Case dblTaxableWage
            Case Is < 0
                MessageBox.Show("Please input a positive numeric value")
            Case Is < 200
                dblFedTax = 8.4 + (dblTaxableWage * 0.1)
            Case Is < 1302
                dblFedTax = 82.35 + (dblTaxableWage * 0.15)
            Case Is < 1687
                dblFedTax = 321.54 + (dblTaxableWage * 0.27)
            Case Is < 7225
                dblFedTax = 440.44 + (dblTaxableWage * 0.28)
            Case Is >= 7225
                dblFedTax = 2085.13 + (dblTaxableWage * 0.35)
        End Select

        Return dblFedTax
    End Function
    Function CalcFedTaxMarried(ByVal dblTaxableWage As Double) As Double
        'calculates Federal taxes if you are married
        Dim dblFedTax As Double

        'goes through the Married Table
        Select Case dblTaxableWage
            Case Is < 0
                MessageBox.Show("Please input a positive numeric value")
            Case Is < 471
                dblFedTax = 0 + (dblTaxableWage * 0.1)
            Case Is < 1809
                dblFedTax = 168.8 + (dblTaxableWage * 0.15)
            Case Is < 2789
                dblFedTax = 412.39 + (dblTaxableWage * 0.27)
            Case Is < 7335
                dblFedTax = 900.66 + (dblTaxableWage * 0.28)
            Case Is >= 7335
                dblFedTax = 1944.12 + (dblTaxableWage * 0.35)
        End Select

        Return dblFedTax
    End Function
    Function CalcNetPay(ByVal dblGrossPay As Double, ByVal dblFedTax As Double, ByVal dblFICA As Double) As Double
        'calculates the Net Pay
        Dim dblNetPay As Double

        dblNetPay = dblGrossPay - dblFICA - dblFedTax

        Return dblNetPay
    End Function

    Private Sub btnCalc_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnCalc.Click
        'set variables
        Dim intHoursWorked As Integer       'inputted hours worked
        Dim intDependents As Integer        'number of dependents from forms 1 and 2
        Dim dblHourlyWage As Double         'hourly wage from forms 1 and 2
        Dim dblGrossPay As Double           'Calculated Gross Pay
        Dim dblFICA As Double               'Calculated FICA Tax
        Dim dblTaxableWage As Double        'Calculated Federal Tax
        Dim dblNetPay As Double             'Calculated Net Pay

        'error handling
        If Integer.TryParse(txtHoursWorked.Text, intHoursWorked) Then
            'calls the gross pay function
            dblGrossPay = CalcGrossPay(dblHourlyWage, intHoursWorked)
            'calls the FICA tax function
            dblFICA = CalcFICA(dblGrossPay)
            'calls taxable wage function
            dblTaxableWage = CalcTaxableWage(dblGrossPay, intDependents, dblFICA)

            'calls either single or married federal tax function
            'If "Married" then
            'dblFedTax = CalcFedTaxMarried(dblTaxableWage)
            'Else
            'dblFedTax = CalcFedTaxSingle(dblTaxableWage)

            'calls net pay function
            'dblNetPay = CalcNetPay(dblGrossPay, dblFICA, dblFedTax)

            'lblFirstName.Text =
            'lblLastName.Text =
            'lblEmployeeID.Text =
            'lblDept.Text =
            'lblHourlyWage.Text =
            lblHoursWorked.Text = intHoursWorked.ToString()
            lblGrossPay.Text = dblGrossPay.ToString("c")
            lblFICA.Text = dblFICA.ToString("c")
            'lblFedTax.Text = dblFedTax.ToString("c")
            'lblNetPay = dblNetPay.ToString("c")


        Else
            MessageBox.Show("Please input a positive whole number for hours worked", "Error: Hours Worked",
                            MessageBoxButtons.OK, MessageBoxIcon.Error)
        End If

    End Sub

    Private Sub mnuFileExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuFileExit.Click
        'closes the form
        Me.Close()
    End Sub

    Private Sub mnuFilePrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuFilePrint.Click
        'prints the document
        PrintDocument1.Print()
    End Sub

    Private Sub mnuFilePreview_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuFilePreview.Click
        'sets the print preview to the print document object
        PrintPreviewDialog1.Document = PrintDocument1
        'shows the print preview
        PrintPreviewDialog1.ShowDialog()
    End Sub

    Private Sub mnuHelpAbout_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuHelpAbout.Click
        'shows the about form
        AboutBox1.ShowDialog()
    End Sub
End Class